runner

package
v0.96.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 15, 2026 License: Apache-2.0 Imports: 24 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewRunnerDataSource

func NewRunnerDataSource() datasource.DataSource

NewRunnerDataSource is a helper function to simplify the provider implementation

func NewRunnerResource

func NewRunnerResource() resource.Resource

NewRunnerResource is a helper function to simplify the provider implementation.

Types

type Model

type Model struct {
	Id                 types.String `tfsdk:"id"` // needed by TF
	ProjectId          types.String `tfsdk:"project_id"`
	RunnerId           types.String `tfsdk:"runner_id"`
	Name               types.String `tfsdk:"name"`
	Description        types.String `tfsdk:"description"`
	Labels             types.Map    `tfsdk:"labels"`
	MaxMessageSizeKiB  types.Int32  `tfsdk:"max_message_size_kib"`
	MaxMessagesPerHour types.Int32  `tfsdk:"max_messages_per_hour"`
	Region             types.String `tfsdk:"region"`
}

Model is the internal model of the terraform resource

Jump to