Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewUserDataSource ¶
func NewUserDataSource() datasource.DataSource
NewUserDataSource is a helper function to simplify the provider implementation.
func NewUserResource ¶
NewUserResource is a helper function to simplify the provider implementation.
Types ¶
type DataSourceModel ¶
type DataSourceModel struct {
Id types.String `tfsdk:"id"` // needed by TF
UserId types.String `tfsdk:"user_id"`
InstanceId types.String `tfsdk:"instance_id"`
ProjectId types.String `tfsdk:"project_id"`
Username types.String `tfsdk:"username"`
Roles types.Set `tfsdk:"roles"`
Host types.String `tfsdk:"host"`
Port types.Int64 `tfsdk:"port"`
Region types.String `tfsdk:"region"`
}
type Model ¶
type Model struct {
Id types.String `tfsdk:"id"` // needed by TF
UserId types.String `tfsdk:"user_id"`
InstanceId types.String `tfsdk:"instance_id"`
ProjectId types.String `tfsdk:"project_id"`
Username types.String `tfsdk:"username"`
Roles types.Set `tfsdk:"roles"`
Password types.String `tfsdk:"password"`
Host types.String `tfsdk:"host"`
Port types.Int64 `tfsdk:"port"`
Uri types.String `tfsdk:"uri"`
Region types.String `tfsdk:"region"`
// RotateWhenChanged is a map of arbitrary key/value pairs that will force
// recreation of the resource when they change, enabling resource rotation based on
// external conditions such as a rotating timestamp. Changing this forces a new
// resource to be created.
RotateWhenChanged types.Map `tfsdk:"rotate_when_changed"`
}
Click to show internal directories.
Click to hide internal directories.